@@ -23,8 +23,6 @@ import contextlib
 import hashlib
 import os
 
-import six
-
 from cinderclient.apiclient import base as common_base
 from cinderclient import exceptions
 from cinderclient import utils
@@ -153,7 +151,7 @@ class Manager(common_base.HookableMixin):
 
         if offset:
             query_params['offset'] = offset
-        query_params = utils.unicode_key_value_to_string(query_params)
+        query_params = query_params
         # Transform the dict to a sequence of two-element tuples in fixed
         # order, then the encoded string will be consistent in Python 2&3.
 
@@ -188,7 +186,7 @@ class Manager(common_base.HookableMixin):
         if not sort:
             return None
 
-        if isinstance(sort, six.string_types):
+        if isinstance(sort, str):
             # Convert the string into a list for consistent validation
             sort = [s for s in sort.split(',') if s]
 
@@ -331,8 +329,28 @@ class Manager(common_base.HookableMixin):
         else:
             return self.resource_class(self, body, loaded=True)
 
+    def _get_all_with_base_url(self, url, response_key=None):
+        resp, body = self.api.client.get_with_base_url(url)
+        if response_key:
+            if isinstance(body[response_key], list):
+                return [self.resource_class(self, res, loaded=True)
+                        for res in body[response_key] if res]
+            return self.resource_class(self, body[response_key],
+                                       loaded=True)
+        return self.resource_class(self, body, loaded=True)
 
-class ManagerWithFind(six.with_metaclass(abc.ABCMeta, Manager)):
+    def _create_update_with_base_url(self, url, body, response_key=None):
+        resp, body = self.api.client.create_update_with_base_url(
+            url, body=body)
+        if response_key:
+            return self.resource_class(self, body[response_key], loaded=True)
+        return self.resource_class(self, body, loaded=True)
+
+    def _delete_with_base_url(self, url, response_key=None):
+        self.api.client.delete_with_base_url(url)
+
+
+class ManagerWithFind(Manager, metaclass=abc.ABCMeta):
     """
     Like a `Manager`, but with additional `find()`/`findall()` methods.
     """
