@@ -12,9 +12,11 @@
 # limitations under the License.
 
 import argparse
+import io
 import re
 import sys
 import unittest
+from unittest import mock
 
 import ddt
 import fixtures
@@ -22,9 +24,7 @@ import keystoneauth1.exceptions as ks_exc
 from keystoneauth1.exceptions import DiscoveryFailure
 from keystoneauth1.identity.generic.password import Password as ks_password
 from keystoneauth1 import session
-import mock
 import requests_mock
-from six import moves
 from testtools import matchers
 
 import cinderclient
@@ -64,7 +64,7 @@ class ShellTest(utils.TestCase):
     def shell(self, argstr):
         orig = sys.stdout
         try:
-            sys.stdout = moves.StringIO()
+            sys.stdout = io.StringIO()
             _shell = shell.OpenStackCinderShell()
             _shell.main(argstr.split())
         except SystemExit:
@@ -148,6 +148,18 @@ class ShellTest(utils.TestCase):
             self.assertThat(help_text,
                             matchers.MatchesRegex(r, re.DOTALL | re.MULTILINE))
 
+    def test_help_arg_no_subcommand(self):
+        required = [
+            r'.*?^usage: ',
+            r'.*?(?m)^\s+create\s+Creates a volume.',
+            r'.*?(?m)^\s+summary\s+Get volumes summary.',
+            r'.*?(?m)^Run "cinder help SUBCOMMAND" for help on a subcommand.',
+        ]
+        help_text = self.shell('--os-volume-api-version 3.40')
+        for r in required:
+            self.assertThat(help_text,
+                            matchers.MatchesRegex(r, re.DOTALL | re.MULTILINE))
+
     @ddt.data('backup-create --help', '--help backup-create')
     def test_dash_dash_help_on_subcommand(self, cmd):
         required = ['.*?^Creates a volume backup.']
@@ -240,7 +252,7 @@ class ShellTest(utils.TestCase):
     def test_noauth_plugin(self, mocker):
         os_auth_url = "http://example.com/v2"
         mocker.register_uri('GET',
-                            "%s/admin/volumes/detail"
+                            "%s/volumes/detail"
                             % os_auth_url, text='{"volumes": []}')
         _shell = shell.OpenStackCinderShell()
         args = ['--os-endpoint', os_auth_url,
