@@ -29,19 +29,6 @@ class VolumesTest(utils.TestCase):
         cs.assert_called('GET', '/volumes/detail?limit=2&marker=1234')
         self._assert_request_id(lst)
 
-    def test_list_volumes_with_sort_key_dir(self):
-        lst = cs.volumes.list(sort_key='id', sort_dir='asc')
-        cs.assert_called('GET', '/volumes/detail?sort_dir=asc&sort_key=id')
-        self._assert_request_id(lst)
-
-    def test_list_volumes_with_invalid_sort_key(self):
-        self.assertRaises(ValueError,
-                          cs.volumes.list, sort_key='invalid', sort_dir='asc')
-
-    def test_list_volumes_with_invalid_sort_dir(self):
-        self.assertRaises(ValueError,
-                          cs.volumes.list, sort_key='id', sort_dir='invalid')
-
     def test__list(self):
         # There only 2 volumes available for our tests, so we set limit to 2.
         limit = 2
@@ -90,22 +77,17 @@ class VolumesTest(utils.TestCase):
 
     def test_create_volume_with_hint(self):
         vol = cs.volumes.create(1, scheduler_hints='uuid')
-        expected = {'volume': {'status': 'creating',
-                               'description': None,
+        expected = {'volume': {'description': None,
                                'availability_zone': None,
                                'source_volid': None,
                                'snapshot_id': None,
                                'size': 1,
-                               'user_id': None,
                                'name': None,
                                'imageRef': None,
-                               'attach_status': 'detached',
                                'volume_type': None,
-                               'project_id': None,
                                'metadata': {},
-                               'source_replica': None,
                                'consistencygroup_id': None,
-                               'multiattach': False},
+                               },
                     'OS-SCH-HNT:scheduler_hints': 'uuid'}
         cs.assert_called('POST', '/volumes', body=expected)
         self._assert_request_id(vol)
@@ -305,22 +287,6 @@ class VolumesTest(utils.TestCase):
         cs.volume_snapshots.list_manageable('host1', detailed=True)
         cs.assert_called('GET', '/os-snapshot-manage/detail?host=host1')
 
-    def test_replication_promote(self):
-        v = cs.volumes.get('1234')
-        self._assert_request_id(v)
-        vol = cs.volumes.promote(v)
-        cs.assert_called('POST', '/volumes/1234/action',
-                         {'os-promote-replica': None})
-        self._assert_request_id(vol)
-
-    def test_replication_reenable(self):
-        v = cs.volumes.get('1234')
-        self._assert_request_id(v)
-        vol = cs.volumes.reenable(v)
-        cs.assert_called('POST', '/volumes/1234/action',
-                         {'os-reenable-replica': None})
-        self._assert_request_id(vol)
-
     def test_get_pools(self):
         vol = cs.volumes.get_pools('')
         cs.assert_called('GET', '/scheduler-stats/get_pools')
@@ -366,21 +332,10 @@ class FormatSortParamTestCase(utils.TestCase):
         self.assertEqual('id:asc,status,size:desc',
                          cs.volumes._format_sort_param(s))
 
-    def test_format_sort_list_of_tuples(self):
-        s = [('id', 'asc'), 'status', ('size', 'desc')]
-        self.assertEqual('id:asc,status,size:desc',
-                         cs.volumes._format_sort_param(s))
-
-    def test_format_sort_list_of_strings_and_tuples(self):
-        s = [('id', 'asc'), 'status', 'size:desc']
-        self.assertEqual('id:asc,status,size:desc',
-                         cs.volumes._format_sort_param(s))
-
     def test_format_sort_invalid_direction(self):
         for s in ['id:foo',
                   'id:asc,status,size:foo',
-                  ['id', 'status', 'size:foo'],
-                  ['id', 'status', ('size', 'foo')]]:
+                  ['id', 'status', 'size:foo']]:
             self.assertRaises(ValueError,
                               cs.volumes._format_sort_param,
                               s)
