@@ -38,12 +38,12 @@
 #                                                   'volume_id': '1234'})
 #             return original(manager, name_or_id, **kwargs)
 
+from unittest import mock
+from urllib import parse
+
 import ddt
 import fixtures
-import mock
 from requests_mock.contrib import fixture as requests_mock_fixture
-import six
-from six.moves.urllib import parse
 
 import cinderclient
 from cinderclient import api_versions
@@ -51,15 +51,14 @@ from cinderclient import base
 from cinderclient import client
 from cinderclient import exceptions
 from cinderclient import shell
+from cinderclient.tests.unit.fixture_data import keystone_client
+from cinderclient.tests.unit import utils
+from cinderclient.tests.unit.v3 import fakes
 from cinderclient import utils as cinderclient_utils
 from cinderclient.v3 import attachments
 from cinderclient.v3 import volume_snapshots
 from cinderclient.v3 import volumes
 
-from cinderclient.tests.unit.fixture_data import keystone_client
-from cinderclient.tests.unit import utils
-from cinderclient.tests.unit.v3 import fakes
-
 
 @ddt.ddt
 @mock.patch.object(client, 'Client', fakes.FakeClient)
@@ -149,6 +148,24 @@ class ShellTest(utils.TestCase):
              u'list --filters name=abc --filters size=1',
          'expected':
              '/volumes/detail?name=abc&size=1'},
+        {'command':
+             u'list --filters created_at=lt:2020-01-15T00:00:00',
+         'expected':
+             '/volumes/detail?created_at=lt%3A2020-01-15T00%3A00%3A00'},
+        {'command':
+             u'list --filters updated_at=gte:2020-02-01T00:00:00,'
+             u'lt:2020-03-01T00:00:00',
+         'expected':
+             '/volumes/detail?updated_at=gte%3A2020-02-01T00%3A00%3A00%2C'
+             'lt%3A2020-03-01T00%3A00%3A00'},
+        {'command':
+             u'list --filters updated_at=gte:2020-02-01T00:00:00,'
+             u'lt:2020-03-01T00:00:00 --filters created_at='
+             u'lt:2020-01-15T00:00:00',
+         'expected':
+             '/volumes/detail?created_at=lt%3A2020-01-15T00%3A00%3A00'
+             '&updated_at=gte%3A2020-02-01T00%3A00%3A00%2C'
+             'lt%3A2020-03-01T00%3A00%3A00'},
         # testcases for list group
         {'command':
              'group-list --filters name=456',
@@ -303,7 +320,7 @@ class ShellTest(utils.TestCase):
         self.assert_call_contained(
             parse.urlencode(
                 {'extra_specs':
-                    {six.text_type('key'): six.text_type('value')}}))
+                    {'key': 'value'}}))
         self.assert_call_contained(parse.urlencode({'is_public': None}))
 
     def test_type_list_public(self):
@@ -1068,8 +1085,8 @@ class ShellTest(utils.TestCase):
     def test_group_failover_replication(self, attach_vol, backend):
         attach = '--allow-attached-volume ' if attach_vol else ''
         backend_id = ('--secondary-backend-id ' + backend) if backend else ''
-        cmd = ('--os-volume-api-version 3.38 group-failover-replication 1234 '
-               + attach + backend_id)
+        cmd = ('--os-volume-api-version 3.38 '
+               'group-failover-replication 1234 ' + attach + backend_id)
         self.run_command(cmd)
         expected = {'failover_replication':
                     {'allow_attached_volume': attach_vol,
@@ -1131,11 +1148,7 @@ class ShellTest(utils.TestCase):
                           self.run_command, '--os-volume-api-version 3.32 '
                           'service-set-log')
         set_levels_mock.assert_not_called()
-        # Different error message from argparse library in Python 2 and 3
-        if six.PY3:
-            msg = 'the following arguments are required: <log-level>'
-        else:
-            msg = 'too few arguments'
+        msg = 'the following arguments are required: <log-level>'
         error_mock.assert_called_once_with(msg)
 
     @ddt.data('debug', 'DEBUG', 'info', 'INFO', 'warning', 'WARNING', 'error',
@@ -1165,7 +1178,6 @@ class ShellTest(utils.TestCase):
         volume = self.shell.cs.volumes.get('1234')
         info = dict()
         info.update(volume._info)
-        info.pop('links', None)
         self.assertEqual(1, poll_method.call_count)
         timeout_period = 3600
         poll_method.assert_has_calls([mock.call(self.shell.cs.volumes.get,
@@ -1443,3 +1455,340 @@ class ShellTest(utils.TestCase):
             '--os-volume-api-version 3.59 transfer-list')
         url = ('/volume-transfers/detail')
         self.assert_called('GET', url)
+
+    def test_subcommand_parser(self):
+        """Ensure that all the expected commands show up.
+
+        This test ensures that refactoring code does not somehow result in
+        a command accidentally ceasing to exist.
+
+        TODO: add a similar test for 3.59 or so
+        """
+        p = self.shell.get_subcommand_parser(api_versions.APIVersion("3.0"),
+                                             input_args=['help'], do_help=True)
+        help_text = p.format_help()
+
+        # These are v3.0 commands only
+        expected_commands = ('absolute-limits',
+                             'api-version',
+                             'availability-zone-list',
+                             'backup-create',
+                             'backup-delete',
+                             'backup-export',
+                             'backup-import',
+                             'backup-list',
+                             'backup-reset-state',
+                             'backup-restore',
+                             'backup-show',
+                             'cgsnapshot-create',
+                             'cgsnapshot-delete',
+                             'cgsnapshot-list',
+                             'cgsnapshot-show',
+                             'consisgroup-create',
+                             'consisgroup-create-from-src',
+                             'consisgroup-delete',
+                             'consisgroup-list',
+                             'consisgroup-show',
+                             'consisgroup-update',
+                             'create',
+                             'delete',
+                             'encryption-type-create',
+                             'encryption-type-delete',
+                             'encryption-type-list',
+                             'encryption-type-show',
+                             'encryption-type-update',
+                             'extend',
+                             'extra-specs-list',
+                             'failover-host',
+                             'force-delete',
+                             'freeze-host',
+                             'get-capabilities',
+                             'get-pools',
+                             'image-metadata',
+                             'image-metadata-show',
+                             'list',
+                             'manage',
+                             'metadata',
+                             'metadata-show',
+                             'metadata-update-all',
+                             'migrate',
+                             'qos-associate',
+                             'qos-create',
+                             'qos-delete',
+                             'qos-disassociate',
+                             'qos-disassociate-all',
+                             'qos-get-association',
+                             'qos-key',
+                             'qos-list',
+                             'qos-show',
+                             'quota-class-show',
+                             'quota-class-update',
+                             'quota-defaults',
+                             'quota-delete',
+                             'quota-show',
+                             'quota-update',
+                             'quota-usage',
+                             'rate-limits',
+                             'readonly-mode-update',
+                             'rename',
+                             'reset-state',
+                             'retype',
+                             'service-disable',
+                             'service-enable',
+                             'service-list',
+                             'set-bootable',
+                             'show',
+                             'snapshot-create',
+                             'snapshot-delete',
+                             'snapshot-list',
+                             'snapshot-manage',
+                             'snapshot-metadata',
+                             'snapshot-metadata-show',
+                             'snapshot-metadata-update-all',
+                             'snapshot-rename',
+                             'snapshot-reset-state',
+                             'snapshot-show',
+                             'snapshot-unmanage',
+                             'thaw-host',
+                             'transfer-accept',
+                             'transfer-create',
+                             'transfer-delete',
+                             'transfer-list',
+                             'transfer-show',
+                             'type-access-add',
+                             'type-access-list',
+                             'type-access-remove',
+                             'type-create',
+                             'type-default',
+                             'type-delete',
+                             'type-key',
+                             'type-list',
+                             'type-show',
+                             'type-update',
+                             'unmanage',
+                             'upload-to-image',
+                             'version-list',
+                             'bash-completion',
+                             'help',)
+
+        for e in expected_commands:
+            self.assertIn('    ' + e, help_text)
+
+    @ddt.data(
+        # testcases for list transfers
+        {'command':
+            'transfer-list --filters volume_id=456',
+         'expected':
+             '/os-volume-transfer/detail?volume_id=456'},
+        {'command':
+             'transfer-list --filters id=123',
+         'expected':
+             '/os-volume-transfer/detail?id=123'},
+        {'command':
+             'transfer-list --filters name=abc',
+         'expected':
+             '/os-volume-transfer/detail?name=abc'},
+        {'command':
+             'transfer-list --filters name=abc --filters volume_id=456',
+         'expected':
+             '/os-volume-transfer/detail?name=abc&volume_id=456'},
+        {'command':
+             'transfer-list --filters id=123 --filters volume_id=456',
+         'expected':
+             '/os-volume-transfer/detail?id=123&volume_id=456'},
+        {'command':
+             'transfer-list --filters id=123 --filters name=abc',
+         'expected':
+             '/os-volume-transfer/detail?id=123&name=abc'},
+    )
+    @ddt.unpack
+    def test_transfer_list_with_filters(self, command, expected):
+        self.run_command('--os-volume-api-version 3.52 %s' % command)
+        self.assert_called('GET', expected)
+
+    def test_default_type_set(self):
+        self.run_command('--os-volume-api-version 3.62 default-type-set '
+                         '4c298f16-e339-4c80-b934-6cbfcb7525a0 '
+                         '629632e7-99d2-4c40-9ae3-106fa3b1c9b7')
+        body = {
+            'default_type':
+                {
+                    'volume_type': '4c298f16-e339-4c80-b934-6cbfcb7525a0'
+                }
+            }
+        self.assert_called(
+            'PUT', 'v3/default-types/629632e7-99d2-4c40-9ae3-106fa3b1c9b7',
+            body=body)
+
+    def test_default_type_list_project(self):
+        self.run_command('--os-volume-api-version 3.62 default-type-list '
+                         '--project-id 629632e7-99d2-4c40-9ae3-106fa3b1c9b7')
+        self.assert_called(
+            'GET', 'v3/default-types/629632e7-99d2-4c40-9ae3-106fa3b1c9b7')
+
+    def test_default_type_list(self):
+        self.run_command('--os-volume-api-version 3.62 default-type-list')
+        self.assert_called('GET', 'v3/default-types')
+
+    def test_default_type_delete(self):
+        self.run_command('--os-volume-api-version 3.62 default-type-unset '
+                         '629632e7-99d2-4c40-9ae3-106fa3b1c9b7')
+        self.assert_called(
+            'DELETE', 'v3/default-types/629632e7-99d2-4c40-9ae3-106fa3b1c9b7')
+
+    def test_restore(self):
+        self.run_command('backup-restore 1234')
+        self.assert_called('POST', '/backups/1234/restore')
+
+    def test_restore_with_name(self):
+        self.run_command('backup-restore 1234 --name restore_vol')
+        expected = {'restore': {'volume_id': None, 'name': 'restore_vol'}}
+        self.assert_called('POST', '/backups/1234/restore',
+                           body=expected)
+
+    def test_restore_with_name_error(self):
+        self.assertRaises(exceptions.CommandError, self.run_command,
+                          'backup-restore 1234 --volume fake_vol --name '
+                          'restore_vol')
+
+    def test_restore_with_az(self):
+        self.run_command('--os-volume-api-version 3.47 backup-restore 1234 '
+                         '--name restore_vol --availability-zone restore_az')
+        expected = {'volume': {'size': 10,
+                               'name': 'restore_vol',
+                               'availability_zone': 'restore_az',
+                               'backup_id': '1234',
+                               'metadata': {},
+                               'imageRef': None,
+                               'source_volid': None,
+                               'consistencygroup_id': None,
+                               'snapshot_id': None,
+                               'volume_type': None,
+                               'description': None}}
+        self.assert_called('POST', '/volumes', body=expected)
+
+    def test_restore_with_az_microversion_error(self):
+        self.assertRaises(exceptions.UnsupportedAttribute, self.run_command,
+                          '--os-volume-api-version 3.46 backup-restore 1234 '
+                          '--name restore_vol --availability-zone restore_az')
+
+    def test_restore_with_volume_type(self):
+        self.run_command('--os-volume-api-version 3.47 backup-restore 1234 '
+                         '--name restore_vol --volume-type restore_type')
+        expected = {'volume': {'size': 10,
+                               'name': 'restore_vol',
+                               'volume_type': 'restore_type',
+                               'backup_id': '1234',
+                               'metadata': {},
+                               'imageRef': None,
+                               'source_volid': None,
+                               'consistencygroup_id': None,
+                               'snapshot_id': None,
+                               'availability_zone': None,
+                               'description': None}}
+        self.assert_called('POST', '/volumes', body=expected)
+
+    def test_restore_with_volume_type_microversion_error(self):
+        self.assertRaises(exceptions.UnsupportedAttribute, self.run_command,
+                          '--os-volume-api-version 3.46 backup-restore 1234 '
+                          '--name restore_vol --volume-type restore_type')
+
+    def test_restore_with_volume_type_and_az_no_name(self):
+        self.run_command('--os-volume-api-version 3.47 backup-restore 1234 '
+                         '--volume-type restore_type '
+                         '--availability-zone restore_az')
+        expected = {'volume': {'size': 10,
+                               'name': 'restore_backup_1234',
+                               'volume_type': 'restore_type',
+                               'availability_zone': 'restore_az',
+                               'backup_id': '1234',
+                               'metadata': {},
+                               'imageRef': None,
+                               'source_volid': None,
+                               'consistencygroup_id': None,
+                               'snapshot_id': None,
+                               'description': None}}
+        self.assert_called('POST', '/volumes', body=expected)
+
+    @ddt.data(
+        {
+            'volume': '1234',
+            'name': None,
+            'volume_type': None,
+            'availability_zone': None,
+        }, {
+            'volume': '1234',
+            'name': 'ignored',
+            'volume_type': None,
+            'availability_zone': None,
+        }, {
+            'volume': None,
+            'name': 'sample-volume',
+            'volume_type': 'sample-type',
+            'availability_zone': None,
+        }, {
+            'volume': None,
+            'name': 'sample-volume',
+            'volume_type': None,
+            'availability_zone': 'az1',
+        }, {
+            'volume': None,
+            'name': 'sample-volume',
+            'volume_type': None,
+            'availability_zone': 'different-az',
+        }, {
+            'volume': None,
+            'name': None,
+            'volume_type': None,
+            'availability_zone': 'different-az',
+        },
+    )
+    @ddt.unpack
+    @mock.patch('cinderclient.utils.print_dict')
+    @mock.patch('cinderclient.tests.unit.v2.fakes._stub_restore')
+    def test_do_backup_restore(self,
+                               mock_stub_restore,
+                               mock_print_dict,
+                               volume,
+                               name,
+                               volume_type,
+                               availability_zone):
+
+        # Restore from the fake '1234' backup.
+        cmd = '--os-volume-api-version 3.47 backup-restore 1234'
+
+        if volume:
+            cmd += ' --volume %s' % volume
+        if name:
+            cmd += ' --name %s' % name
+        if volume_type:
+            cmd += ' --volume-type %s' % volume_type
+        if availability_zone:
+            cmd += ' --availability-zone %s' % availability_zone
+
+        if name or volume:
+            volume_name = 'sample-volume'
+        else:
+            volume_name = 'restore_backup_1234'
+
+        mock_stub_restore.return_value = {'volume_id': '1234',
+                                          'volume_name': volume_name}
+
+        self.run_command(cmd)
+
+        # Check whether mock_stub_restore was called in order to determine
+        # whether the restore command invoked the backup-restore API. If
+        # mock_stub_restore was not called then this indicates the command
+        # invoked the volume-create API to restore the backup to a new volume
+        # of a specific volume type, or in a different AZ (the fake '1234'
+        # backup is in az1).
+        if volume_type or availability_zone == 'different-az':
+            mock_stub_restore.assert_not_called()
+        else:
+            mock_stub_restore.assert_called_once()
+
+        mock_print_dict.assert_called_once_with({
+            'backup_id': '1234',
+            'volume_id': '1234',
+            'volume_name': volume_name,
+            })
