@@ -15,8 +15,6 @@
 
 """Volume interface (v2 extension)."""
 
-import warnings
-
 from cinderclient.apiclient import base as common_base
 from cinderclient import base
 
@@ -233,8 +231,7 @@ class VolumeManager(base.ManagerWithFind):
                source_volid=None, name=None, description=None,
                volume_type=None, user_id=None,
                project_id=None, availability_zone=None,
-               metadata=None, imageRef=None, scheduler_hints=None,
-               multiattach=False):
+               metadata=None, imageRef=None, scheduler_hints=None):
         """Create a volume.
 
         :param size: Size of volume in GB
@@ -251,8 +248,6 @@ class VolumeManager(base.ManagerWithFind):
         :param source_volid: ID of source volume to clone from
         :param scheduler_hints: (optional extension) arbitrary key-value pairs
                             specified by the client to help boot an instance
-        :param multiattach: Allow the volume to be attached to more than
-                            one instance (deprecated)
         :rtype: :class:`Volume`
         """
         if metadata is None:
@@ -260,13 +255,6 @@ class VolumeManager(base.ManagerWithFind):
         else:
             volume_metadata = metadata
 
-        if multiattach:
-            warnings.warn('The ``multiattach`` volume create flag is '
-                          'deprecated and will be removed in a future '
-                          'release. Multiattach capability is now controlled '
-                          'using volume type extra specs.',
-                          DeprecationWarning)
-
         body = {'volume': {'size': size,
                            'consistencygroup_id': consistencygroup_id,
                            'snapshot_id': snapshot_id,
@@ -277,7 +265,6 @@ class VolumeManager(base.ManagerWithFind):
                            'metadata': volume_metadata,
                            'imageRef': imageRef,
                            'source_volid': source_volid,
-                           'multiattach': multiattach,
                            }}
 
         if scheduler_hints:
@@ -294,7 +281,7 @@ class VolumeManager(base.ManagerWithFind):
         return self._get("/volumes/%s" % volume_id, "volume")
 
     def list(self, detailed=True, search_opts=None, marker=None, limit=None,
-             sort_key=None, sort_dir=None, sort=None):
+             sort=None):
         """Lists all volumes.
 
         :param detailed: Whether to return detailed volume info.
@@ -302,9 +289,6 @@ class VolumeManager(base.ManagerWithFind):
         :param marker: Begin returning volumes that appear later in the volume
                        list than that represented by this volume id.
         :param limit: Maximum number of volumes to return.
-        :param sort_key: Key to be sorted; deprecated in kilo
-        :param sort_dir: Sort direction, should be 'desc' or 'asc'; deprecated
-                         in kilo
         :param sort: Sort information
         :rtype: list of :class:`Volume`
         """
@@ -312,8 +296,7 @@ class VolumeManager(base.ManagerWithFind):
         resource_type = "volumes"
         url = self._build_list_url(resource_type, detailed=detailed,
                                    search_opts=search_opts, marker=marker,
-                                   limit=limit, sort_key=sort_key,
-                                   sort_dir=sort_dir, sort=sort)
+                                   limit=limit, sort=sort)
         return self._list(url, resource_type, limit=limit)
 
     def delete(self, volume, cascade=False):
