@@ -13,4 +13,4 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from cinderclient.v2.limits import *  # flake8: noqa
+from cinderclient.v2.limits import *  # noqa
